@@ -1502,6 +1502,20 @@ class CU1Gate(BasicGate):
 
         return _CU1
 
+    def build_gate(self):
+        from QuICT.core.gate import CompositeGate
+
+        cgate = CompositeGate()
+        with cgate:
+            CRz(self.parg) & [0, 1]
+            U1(self.parg / 2) & 0
+
+        args = self.cargs + self.targs
+        if len(args) == self.controls + self.targets:
+            cgate & args
+
+        return cgate
+
 
 CU1 = CU1Gate()
 
@@ -1564,6 +1578,19 @@ class CU3Gate(BasicGate):
 
         return _CU3
 
+    def build_gate(self):
+        from QuICT.qcda.synthesis import UnitaryDecomposition
+
+        assert self.controls + self.targets > 0
+        mapping_args = self.cargs + self.targs
+        cgate, _ = UnitaryDecomposition().execute(self.matrix)
+        cgate & mapping_args
+
+        if self._precision == np.complex64:
+            cgate.convert_precision()
+
+        return cgate
+
 
 CU3 = CU3Gate()
 
@@ -2102,7 +2129,7 @@ class UnitaryGate(BasicGate):
         return _U
 
     def build_gate(self):
-        from QuICT.qcda.synthesis.unitary_decomposition import UnitaryDecomposition
+        from QuICT.qcda.synthesis import UnitaryDecomposition
 
         assert self.controls + self.targets > 0
         mapping_args = self.cargs + self.targs
